@@ -508,9 +508,9 @@ PyMethodDef pconvert_functions[3] = {
 
 #if PY_MAJOR_VERSION >= 3
 PyMODINIT_FUNC PyInit_pconvert(void) {
-    /* allocates space for the module object to hold the
-    module to be created */
-    PyObject *pconvert_module;
+    /* allocates space for the multiple python object
+    references to be used in the intialization process */
+    PyObject *pconvert_module, *algorithms;
 
     /* creates the pconvert extension module with the
     functions defined in the previous array, in case
@@ -519,9 +519,16 @@ PyMODINIT_FUNC PyInit_pconvert(void) {
     pconvert_module = PyModule_Create(&moduledef);
     if(pconvert_module == NULL) { return NULL; }
 
+    /* builds the algorithms tuple that will expose the multiple algorithms
+    supported by the pconvert infra-structure */
+    algorithms = Py_BuildValue("sssssssss", PCONVERT_ALGORITHMS);
+
     /* adds a series of constants to the module that are
     going to be exposed to the developer */
     PyModule_AddStringConstant(pconvert_module, "VERSION", PCONVERT_VERSION);
+    PyModule_AddStringConstant(pconvert_module, "COMPILATION_DATE", PCONVERT_COMPILATION_DATE);
+    PyModule_AddStringConstant(pconvert_module, "COMPILATION_TIME", PCONVERT_COMPILATION_TIME);
+    PyModule_AddObject(pconvert_module, "ALGORITHMS", algorithms);
 
     /* returns the module that has just been created to
     the caller method/function (to be used) */
@@ -531,15 +538,22 @@ PyMODINIT_FUNC PyInit_pconvert(void) {
 PyMODINIT_FUNC initpconvert(void) {
     /* allocates space for the module object to hold the
     module to be created */
-    PyObject *pconvert_module;
+    PyObject *pconvert_module, *algorithms;
 
     /* creates the pconvert extension module with the
     functions defined in the previous array */
     pconvert_module = Py_InitModule("pconvert", pconvert_functions);
     if(pconvert_module == NULL) { return; }
 
+    /* builds the algorithms tuple that will expose the multiple algorithms
+    supported by the pconvert infra-structure */
+    algorithms = Py_BuildValue("sssssssss", PCONVERT_ALGORITHMS);
+
     /* adds a series of constants to the module that are
     going to be exposed to the developer */
     PyModule_AddStringConstant(pconvert_module, "VERSION", PCONVERT_VERSION);
+    PyModule_AddStringConstant(pconvert_module, "COMPILATION_DATE", PCONVERT_COMPILATION_DATE);
+    PyModule_AddStringConstant(pconvert_module, "COMPILATION_TIME", PCONVERT_COMPILATION_TIME);
+    PyModule_AddObject(pconvert_module, "ALGORITHMS", algorithms);
 }
 #endif
